==> tekton-model-triggers-v1alpha1-6.5.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ParamSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParamSpecFluentImpl<A extends ParamSpecFluent<A>> extends BaseFluent<A> implements ParamSpecFluent<A>{
  public ParamSpecFluentImpl() {
  }
  public ParamSpecFluentImpl(ParamSpec instance) {
    this.withDefault(instance.getDefault()); 
    this.withDescription(instance.getDescription()); 
    this.withName(instance.getName()); 
  }
  private String _default;
  private String description;
  private String name;
  public String getDefault() {
    return this._default;
  }
  public A withDefault(String _default) {
    this._default=_default; return (A) this;
  }
  public Boolean hasDefault() {
    return this._default != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ParamSpecFluentImpl that = (ParamSpecFluentImpl) o;
    if (_default != null ? !_default.equals(that._default) :that._default != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(_default,  description,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ParamSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParamSpecFluentImpl<A extends ParamSpecFluent<A>> extends BaseFluent<A> implements ParamSpecFluent<A>{
  public ParamSpecFluentImpl() {
  }
  public ParamSpecFluentImpl(ParamSpec instance) {
    if (instance != null) {
      this.withDefault(instance.getDefault());
      this.withDescription(instance.getDescription());
      this.withName(instance.getName());
    }
  }
  private String _default;
  private String description;
  private String name;
  public String getDefault() {
    return this._default;
  }
  public A withDefault(String _default) {
    this._default=_default; return (A) this;
  }
  public Boolean hasDefault() {
    return this._default != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParamSpecFluentImpl that = (ParamSpecFluentImpl) o;
    if (!java.util.Objects.equals(_default, that._default)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(_default,  description,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}
